@@ -8,10 +8,12 @@ RML_est<-rml(y,x,decreasing=decreasing)$RML
   G<-length(dat$y)
   study<-1:G
 
-iy<-matrix(0, nrow=G, ncol=G)
-for (i in 1:G) {
-  for (j in 1:G) {
-    if((dat$y[i]<=dat$y[j])&&(i<j)){
+iy<-matrix(FALSE, nrow=G, ncol=G)
+
+
+for (i in 1:(G-1)) {
+  for (j in (i+1):G) {
+    if((dat$y[i]) <= (dat$y[j])){
       iy[i,j]<-TRUE
     }
     else {iy[i,j]<-FALSE}
@@ -24,7 +26,11 @@ iy2<-1-(sum(iy)==sum(1:(G-1)))
 
 RJS<-(1-(G-2)/(sum((dat$y)^2/s^2)))*(dat$y)*iy1+RML_est*iy2
 
-RJS_plus<-((1-(G-2)/(sum((dat$y)^2/s^2)))>0)*(dat$y)*iy1+RML_est*iy2
+p<-(1-(G-2)/(sum((dat$y)^2/s^2)))
+q<-ifelse(p>0,p,0)
+RJS_plus<-q*(dat$y)*iy1+RML_est*iy2
+
+
 
 
 rjs_table<-data.frame("id"=dat$id, "x"=dat$x,"RJS"=RJS,"RJS_plus"=RJS_plus)
